@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (C) 2013 x265 project
+ * Copyright (C) 2013-2020 MulticoreWare, Inc
  *
  * Authors: Steve Borho <steve@borho.org>
  *
@@ -25,7 +25,7 @@
 #include "yuv.h"
 #include "y4m.h"
 
-using namespace x265;
+using namespace X265_NS;
 
 InputFile* InputFile::open(InputFileInfo& info, bool bForceY4m)
 {
